///////////////////////////////////////////////////////////////////////////////
// Name:        wx/msw/wince/resources.h
// Purpose:     identifiers shared between resource compiler and eVC
// Author:      Wlodzimierz ABX Skiba
// Modified by:
// Created:     01.05.2004
// RCS-ID:      $Id: resources.h 64940 2010-07-13 13:29:13Z VZ $
// Copyright:   (c) Wlodzimierz Skiba
// Licence:     wxWindows licence
///////////////////////////////////////////////////////////////////////////////

// Windows CE dummy menu for SHCreateMenuBar()
#define wxIDM_SHMENU             40000

#define IDM_LEFT                 40001
#define IDM_RIGHT                40002
#define IDM_ITEM                 40003

#define IDS_EMPTY                40010

#define IDR_POPUP_1              40020
#define IDR_POPUP_2              40021

#define IDR_MENUBAR_ONE_BUTTON   40030
#define IDR_MENUBAR_LEFT_MENU    40031
#define IDR_MENUBAR_RIGHT_MENU   40032
#define IDR_MENUBAR_BOTH_MENUS   40033
